@@ -1,4 +1,5 @@
 """implementations"""
+
 from functools import cache
 
 from class_resolver import ClassResolver
@@ -13,9 +14,7 @@ def get_implementation_resolver() -> ClassResolver[PhEvalRunner]:
     Returns:
         ClassResolver[PhEvalRunner]: _description_
     """
-    implementation_resolver: ClassResolver[
-        PhEvalRunner
-    ] = ClassResolver.from_subclasses(
+    implementation_resolver: ClassResolver[PhEvalRunner] = ClassResolver.from_subclasses(
         PhEvalRunner,
         suffix="Implementation",
     )
